@@ -84,6 +84,24 @@ def test_meta_from_array_type_inputs():
     assert da.from_array(np.ones(5).astype(np.int32), meta=np.ndarray).dtype == np.int32
 
 
+def test_meta_from_array_scipy_sparse():
+    pytest.importorskip("scipy.sparse")
+    import scipy.sparse
+
+    # Note: csr_matrix can exclusively have ndim=2
+    x = scipy.sparse.csr_matrix([[2, 3]])
+    meta = meta_from_array(x)
+    assert isinstance(meta, type(x))
+
+    meta = meta_from_array(x, ndim=2)
+    assert isinstance(meta, type(x))
+    assert meta.shape == (0, 0)
+
+    meta = meta_from_array(x, dtype=np.float32)
+    assert isinstance(meta, type(x))
+    assert meta.dtype == np.float32
+
+
 @pytest.mark.parametrize(
     "a,b",
     [
